summaryrefslogtreecommitdiffstats
path: root/tdecore/tests/kprociotest.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/tests/kprociotest.h')
-rw-r--r--tdecore/tests/kprociotest.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/tests/kprociotest.h b/tdecore/tests/kprociotest.h
index 9f948e644..fd60bb87b 100644
--- a/tdecore/tests/kprociotest.h
+++ b/tdecore/tests/kprociotest.h
@@ -1,5 +1,5 @@
//
// DUMMY -- A dummy class with a slot to demonstrate KProcess signals
//
// version 0.2, Aug 2nd 1997
//
@@ -20,7 +20,7 @@ class Dummy : public TQObject
Q_OBJECT
public slots:
- void printMessage(KProcess *proc)
+ void printMessage(TDEProcess *proc)
{
printf("Process %d exited!\n", (int)proc->getPid());
}
@@ -1,5 +1,5 @@
//
-// DUMMY -- A dummy class with a slot to demonstrate KProcess signals
+// DUMMY -- A dummy class with a slot to demonstrate TDEProcess signals
//
// version 0.2, Aug 2nd 1997